@@ -10,10 +10,11 @@
 #else
 # ifdef HAVE_NCURSES_CURSES_H
 #  include <ncurses/curses.h>
-# else
-#ifdef __hpux
-#include <curses_colr/curses.h>
 #else
+# ifdef HAVE_CURSES_COLR_CURSES_H
+#  include <varargs.h>
+#  include <curses_colr/curses.h>
+# else
 #  include <curses.h>
 #  if (defined(__bsdi__) || defined(__NetBSD__)) && !defined(_maxx)
 #   define _maxx maxx
