@@ -1,6 +1,6 @@
 require 'mkmf'
 $LDFLAGS = "-L/usr/local/lib" if File.directory?("/usr/local/lib")
-$CFLAGS ||= ""
+$CFLAGS = "-Dss_family=__ss_family -Dss_len=__ss_len"
 
 case PLATFORM
 when /mswin32/
@@ -100,7 +100,7 @@ EOF
   end
   
   if $ipv6lib
-    if File.directory? $ipv6libdir and File.exist? "#{$ipv6libdir}/#{ipv6lib}.a"
+    if File.directory? $ipv6libdir and File.exist? "#{$ipv6libdir}/lib#{$ipv6lib}.a"
       $LDFLAGS += " -L#$ipv6libdir -l#$ipv6lib"
     else
       print <<EOS
@@ -149,6 +149,8 @@ EOF
     $CFLAGS="-DHAVE_SA_LEN "+$CFLAGS
 end
 
+have_header("sys/sysctl.h")
+
 $getaddr_info_ok = false
 if try_run(<<EOF)
 #include <sys/types.h>
@@ -236,51 +238,31 @@ end
 
 $objs = ["socket.o"]
     
-if $getaddr_info_ok or not $ipv6
-  if have_func("getaddrinfo") and
-     have_func("getnameinfo")
+if $getaddr_info_ok
+  if have_func("getaddrinfo") and have_func("getnameinfo")
     have_getaddrinfo = true
   end
 end
 
 if have_getaddrinfo
-  if try_link(<<EOF)
-#include <sys/types.h>
-#include <netdb.h>
-#include <string.h>
-#include <sys/socket.h>
-#include <netinet/in.h>
-int
-main()
-{
-   struct sockaddr_storage storage;
-   struct sockaddr_storage *addr = 0;
-
-   addr->_ss_family = &storage.__ss_family;
-   addr->_ss_len = &storage.__ss_len;
-   return 0;
-}
-EOF
-    sockaddr_storage=true
-  end
+  $CFLAGS="-DHAVE_GETADDRINFO "+$CFLAGS
 else
   sockaddr_storage=true
   $CFLAGS="-I. "+$CFLAGS
   $objs += "getaddrinfo.o"
   $objs += "getnameinfo.o"
-end
-
-if sockaddr_storage
-  $CFLAGS="-DSOCKADDR_STORAGE=sockaddr_storage "+$CFLAGS
+  have_func("inet_ntop") or have_func("inet_ntoa")
+  have_func("inet_pton") or have_func("inet_aton")
 end
 
 have_header("sys/un.h")
+
 if have_func(test_func)
   have_func("hsterror")
   unless have_func("gethostname")
     have_func("uname")
   end
-  if ENV["SOCKS_SERVER"]  # test if SOCKSsocket needed
+  if ENV["SOCKS_SERVER"] or enable_config("socks", false)
     if have_library("socks", "Rconnect")
       $CFLAGS="-DSOCKS"
     end
