@@ -40,7 +40,9 @@
 
 #include <sys/types.h>
 #include <sys/param.h>
+#ifdef HAVE_SYSCTL_H
 #include <sys/sysctl.h>
+#endif
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <arpa/inet.h>
@@ -48,12 +50,15 @@
 #include <netdb.h>
 #include <resolv.h>
 #include <string.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
 #include <ctype.h>
 #include <unistd.h>
 
+#include "config.h"
 #include "addrinfo.h"
+#include "sockport.h"
 
 #if defined(__KAME__) && defined(INET6)
 # define FAITH
@@ -159,7 +164,7 @@ if (pai->ai_flags & AI_CANONNAME) {\
 	memcpy(ai, pai, sizeof(struct addrinfo));\
 	(ai)->ai_addr = (struct sockaddr *)((ai) + 1);\
 	memset((ai)->ai_addr, 0, (afd)->a_socklen);\
-	SET_SA_LEN(*(ai)->ai_addr, (ai)->ai_addrlen = (afd)->a_socklen);\
+	SET_SA_LEN((ai)->ai_addr, (ai)->ai_addrlen = (afd)->a_socklen);\
 	(ai)->ai_addr->sa_family = (ai)->ai_family = (afd)->a_af;\
 	((struct sockinet *)(ai)->ai_addr)->si_port = port;\
 	p = (char *)((ai)->ai_addr);\
@@ -205,6 +210,39 @@ str_isnumber(p)
 	return YES;
 }
 
+#ifndef HAVE_INET_PTON
+
+static int
+inet_pton(af, hostname, pton)
+	int af;
+	const char *hostname;
+	void *pton;
+{
+	struct in_addr in;
+
+#ifdef HAVE_INET_ATON
+	if (!inet_aton(hostname, &in.s_addr))
+	    return 0;
+#else
+	int d1, d2, d3, d4;
+	char ch;
+
+	if (sscanf(hostname, "%d.%d.%d.%d%c", &d1, &d2, &d3, &d4, &ch) == 4 &&
+	    0 <= d1 && d1 <= 255 && 0 <= d2 && d2 <= 255 &&
+	    0 <= d3 && d3 <= 255 && 0 <= d4 && d4 <= 255) {
+	    in.s_addr = htonl(
+		((long) d1 << 24) | ((long) d2 << 16) |
+		((long) d3 << 8) | ((long) d4 << 0));
+	}
+	else {
+	    return 0;
+	}
+#endif
+	memcpy(pton, &in, sizeof(in));
+	return 1;
+}
+#endif
+
 int
 getaddrinfo(hostname, servname, hints, res)
 	const char *hostname, *servname;
@@ -605,11 +643,3 @@ get_addr(hostname, af, res, pai, port0)
 	*res = NULL;
 	return error;
 }
-
-int
-addrinfo_sockaddr_len(sa)
-    struct sockaddr *sa;
-{
-    /* should support other protocol families */
-    return sizeof(struct sockaddr_in);
-}
