@@ -44,7 +44,9 @@
 #include <string.h>
 #include <stddef.h>
 
+#include "config.h"
 #include "addrinfo.h"
+#include "sockport.h"
 
 #define SUCCESS 0
 #define ANY 0
@@ -80,6 +82,28 @@ struct sockinet {
 #define ENI_FAMILY	5
 #define ENI_SALEN	6
 
+#ifndef HAVE_INET_NTOP
+static const char *
+inet_ntop(af, addr, numaddr, numaddr_len)
+	int af;
+	__const void *addr;
+	char *numaddr;
+	size_t numaddr_len;
+{
+#ifdef HAVE_INET_NTOA
+	struct in_addr in;
+	memcpy(&in.s_addr, addr, sizeof(in.s_addr));
+	strncpy(numaddr, numaddr_len, inet_ntoa(in));
+#else
+	unsigned long x = ntohl(*(unsigned long*)addr);
+	snprintf(numaddr, numaddr_len, "%d.%d.%d.%d",
+		 (int) (x>>24) & 0xff, (int) (x>>16) & 0xff,
+		 (int) (x>> 8) & 0xff, (int) (x>> 0) & 0xff);
+#endif
+	return numaddr;
+}
+#endif
+
 int
 getnameinfo(sa, salen, host, hostlen, serv, servlen, flags)
 	const struct sockaddr *sa;
@@ -101,6 +125,7 @@ getnameinfo(sa, salen, host, hostlen, serv, servlen, flags)
 	int h_error;
 	char numserv[512];
 	char numaddr[512];
+	extern int h_errno;
 
 	if (sa == NULL)
 		return ENI_NOSOCKET;
