@@ -60,7 +60,7 @@ Find.find("lib") do |f|
   File.install f, dir, 0644, true
 end
 
-if PLATFORM =~ /ibm-aix/
+if PLATFORM =~ /-aix/
   File.install "ruby.imp", archdir, 0644, true
 end
 for f in Dir["*.h"]
