@@ -104,7 +104,6 @@ VALUE rb_dvar_ref _((ID));
 void rb_dvar_asgn _((ID, VALUE));
 void rb_dvar_push _((ID, VALUE));
 VALUE rb_eval_cmd _((VALUE, VALUE));
-VALUE rb_trap_eval _((VALUE, int));
 int rb_respond_to _((VALUE, ID));
 void rb_interrupt _((void));
 VALUE rb_apply _((VALUE, ID, VALUE));
@@ -135,6 +134,7 @@ VALUE rb_thread_create _((VALUE (*)(), void*));
 int rb_thread_scope_shared_p _((void));
 void rb_thread_interrupt _((void));
 void rb_thread_trap_eval _((VALUE, int));
+void rb_thread_signal_raise _((char*));
 int rb_thread_select();
 void rb_thread_wait_for();
 VALUE rb_thread_current _((void));
