@@ -3,7 +3,7 @@
   range.c -
 
   $Author: matz $
-  $Date: 1999/04/09 17:57:42 $
+  $Date: 1999/05/06 08:31:43 $
   created at: Thu Aug 19 17:46:47 JST 1993
 
   Copyright (C) 1993-1999 Yukihiro Matsumoto
@@ -74,7 +74,7 @@ range_s_new(argc, argv, klass)
     VALUE beg, end, flag, range;
     
     rb_scan_args(argc, argv, "21", &beg, &end, &flag);
-    if (argc == 2) flag == Qtrue;
+    if (argc == 2) flag = Qfalse;
     return range_new(klass, beg, end, RTEST(flag));
 }
 
