@@ -64,12 +64,12 @@
 /* perl-style extended pattern available */
 #define RE_OPTION_EXTENDED   (RE_OPTION_IGNORECASE<<1)
 /* newline will be included for . and invert charclass matches */
-#define RE_OPTION_POSIX      (RE_OPTION_EXTENDED<<1)
+#define RE_OPTION_POSIXLINE  (RE_OPTION_EXTENDED<<1)
 
-#define RE_MAY_IGNORECASE    (RE_OPTION_POSIX<<1)
+#define RE_MAY_IGNORECASE    (RE_OPTION_POSIXLINE<<1)
 #define RE_OPTIMIZE_ANCHOR   (RE_MAY_IGNORECASE<<1)
 #define RE_OPTIMIZE_EXACTN   (RE_OPTIMIZE_ANCHOR<<1)
-#define RE_OPTIMIZE_NO_BM    (RE_OPTIMIZE_ANCHOR<<1)
+#define RE_OPTIMIZE_NO_BM    (RE_OPTIMIZE_EXACTN<<1)
 
 /* For multi-byte char support */
 #define MBCTYPE_ASCII 0
